@@ -6,7 +6,7 @@
 
 """
 
-__version__ = "0.7.2"
+__version__ = "0.8.0"
 __license__ = 'MIT'
 __author__ = "@byteface"
 
@@ -296,18 +296,26 @@ class domonic:
 
         # fully strip inline css and js
         if not script_tags:
-            scripts = re.compile(r'<(script).*?</\1>(?s)')
+            # scripts = re.compile(r'<(script).*?</\1>(?s)')
+            # TODO fix #DeprecationWarning: Flags not at the start of the expression
+            scripts = re.compile(r'<(script).*?</\1>')
             page = scripts.sub('', page)
 
         if not style_tags:
-            css = re.compile(r'<(style).*?</\1>(?s)')
+            # css = re.compile(r'<(style).*?</\1>(?s)')
+            # TODO fix #DeprecationWarning: Flags not at the start of the expression
+            css = re.compile(r'<(style).*?</\1>', re.DOTALL)
+
             page = css.sub('', page)
 
         # fully strip svg and code tags
         # svg = re.compile(r'<(svg).*?</\1>(?s)')
         # page = svg.sub('', page)
 
-        code = re.compile(r'<(code).*?</\1>(?s)')
+        # code = re.compile(r'<(code).*?</\1>(?s)')
+        # TODO fix #DeprecationWarning: Flags not at the start of the expression
+        code = re.compile(r'<(code).*?</\1>')
+
         page = code.sub('', page)
 
         comments = re.compile(r'<!--(.|\s)*?-->')
@@ -835,7 +843,7 @@ class domonic:
                         next(lines_iterator, None)  # skip the iterator along by 1
 
                 else:
-                    if is_multiline_string == False:
+                    if not is_multiline_string == False:
                         x = line.rindex('"')
                         if x:
                             line = line[:x] + '"""' + line[x + 1:]
@@ -969,6 +977,21 @@ class domonic:
         """ Parse a file into a DOM from a string. """
         # if parser is None:
         # import xml.parsers.expat.ExpatError as ExpatError        # parser = xml.parsers.expat.ParserCreate()
+
+        # TODO - this needs to be off for debugging
+        try:
+            # if users has html5lib installed used that to parse
+            import html5lib
+            if 'html5lib' in sys.modules:
+                from html5lib import HTMLParser
+                from domonic.ext.html5lib_ import getTreeBuilder
+                parser = HTMLParser(tree=getTreeBuilder())
+                page = parser.parse(string)
+                # print('PARSED WITH HTML5 LIB')
+                return page
+        except ImportError:
+            pass
+
         try:
             from domonic.parsers import expatbuilder
             return expatbuilder.parseString(string)
